@@ -28,7 +28,7 @@ class RiskVMPanel(PluginTemplateExtension):
 class RiskDevicePanel(PluginTemplateExtension):
     # model = 'users_and_computers.RiskRelation'
     # model = 'dcim.device'
-    model = 'users_and_computers.Risk'
+    model = 'users_and_computers.risk'
 
     def right_page(self):
         risk = self.context['object']
